# Туториал

[EN](/docs/tutorial/en/0_tutorial.md) | RU

Добро пожаловать в официальный туториал по telegrinder от нашей команды и контрибьюторов. Этот туториал рекомендуется читать по порядку.

Во время чтения, если у вас возникнут вопросы, вы можете зайти в [любой из форумов сообщества](/docs/community_links.md) и задать их. Обратите внимание: issues предназначены исключительно для запросов новых фич и сообщений об багах.

## Содержание

1. [Добро пожаловать в telegrinder. Запускаемся](1_setting_up.md)
2. [Правила](2_rules.md)
3. [Немного функционального программирования](3_functional_bits.md)
4. [Telegram API](4_api.md)
5. [Ноды](5_nodes.md)
6. [Dispatch, разделение кода](6_dispatch.md)
7. [Клавиатура, обработка полезной нагрузки](7_keyboard.md)
8. [Работа с текстом: форматирование, локализация](8_text.md)
9. [Стейты (состояния пользователя): waiters, длинные стейты](9_states.md)
10. [Медиа](10_media.md)
11. [Обработка ошибок](11_handling_errors.md)
12. [Готовые сценарии](12_out-of-box_scenarios.md)
